@@ -7,13 +7,15 @@ from pyfacebook import LibraryError, FacebookError
 
 def test_error():
     error = {
-        "message": "Message describing the error",
-        "type": "OAuthException",
-        "code": 190,
-        "error_subcode": 460,
-        "error_user_title": "A title",
-        "error_user_msg": "A message",
-        "fbtrace_id": "EJplcsCHuLu",
+        "error": {
+            "message": "Message describing the error",
+            "type": "OAuthException",
+            "code": 190,
+            "error_subcode": 460,
+            "error_user_title": "A title",
+            "error_user_msg": "A message",
+            "fbtrace_id": "EJplcsCHuLu",
+        }
     }
 
     fb_err = FacebookError(error)
